export const IDL = {
    "version": "0.1.0",
    "name": "emission_schedule",
    "instructions": [
        {
            "name": "initializeEmissionScheduleV0",
            "accounts": [
                {
                    "name": "schedule",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "rndrMint",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "authority",
                    "isMut": true,
                    "isSigner": true
                },
                {
                    "name": "payer",
                    "isMut": true,
                    "isSigner": true
                },
                {
                    "name": "systemProgram",
                    "isMut": false,
                    "isSigner": false
                }
            ],
            "args": [
                {
                    "name": "args",
                    "type": {
                        "defined": "InitializeEmissionScheduleArgsV0"
                    }
                }
            ]
        },
        {
            "name": "updateEmissionScheduleV0",
            "accounts": [
                {
                    "name": "authority",
                    "isMut": false,
                    "isSigner": true
                },
                {
                    "name": "schedule",
                    "isMut": true,
                    "isSigner": false,
                    "relations": [
                        "authority"
                    ]
                }
            ],
            "args": [
                {
                    "name": "args",
                    "type": {
                        "defined": "UpdateEmissionScheduleArgsV0"
                    }
                }
            ]
        },
        {
            "name": "updateBurnedRenderCreditsV0",
            "accounts": [
                {
                    "name": "emissionSchedule",
                    "isMut": true,
                    "isSigner": false,
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const",
                                "type": "string",
                                "value": "emission_schedule"
                            },
                            {
                                "kind": "account",
                                "type": "publicKey",
                                "account": "Mint",
                                "path": "rndr_mint"
                            }
                        ]
                    }
                },
                {
                    "name": "renderCredits",
                    "isMut": false,
                    "isSigner": true
                },
                {
                    "name": "rcMint",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "rndrMint",
                    "isMut": true,
                    "isSigner": false
                }
            ],
            "args": [
                {
                    "name": "args",
                    "type": {
                        "defined": "UpdateBurnedRenderCreditsArgsV0"
                    }
                }
            ]
        },
        {
            "name": "updateNodeStatsV0",
            "accounts": [
                {
                    "name": "node",
                    "isMut": false,
                    "isSigner": true
                },
                {
                    "name": "emissionSchedule",
                    "isMut": false,
                    "isSigner": false
                },
                {
                    "name": "rndrMint",
                    "isMut": true,
                    "isSigner": false
                }
            ],
            "args": [
                {
                    "name": "args",
                    "type": {
                        "defined": "UpdateNodeStatsArgsV0"
                    }
                }
            ]
        },
        {
            "name": "initializeEmissionScheduleReceiptV0",
            "accounts": [
                {
                    "name": "emissionScheduleReceipt",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "emissionSchedule",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "rndrMint",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "emissionDistributor",
                    "isMut": true,
                    "isSigner": false
                },
                {
                    "name": "distributorThread",
                    "isMut": true,
                    "isSigner": true
                },
                {
                    "name": "payer",
                    "isMut": true,
                    "isSigner": true
                },
                {
                    "name": "systemProgram",
                    "isMut": false,
                    "isSigner": false
                }
            ],
            "args": []
        }
    ],
    "accounts": [
        {
            "name": "emissionScheduleV0",
            "type": {
                "kind": "struct",
                "fields": [
                    {
                        "name": "epochId",
                        "type": "u64"
                    },
                    {
                        "name": "authority",
                        "type": "publicKey"
                    },
                    {
                        "name": "currentEpochBeganAt",
                        "type": "i64"
                    },
                    {
                        "name": "totalRndrBurned",
                        "type": "u64"
                    },
                    {
                        "name": "totalUptimeScore",
                        "type": "u64"
                    },
                    {
                        "name": "totalRenderScore",
                        "type": "u64"
                    },
                    {
                        "name": "epochDurationSec",
                        "type": "i64"
                    },
                    {
                        "name": "emissionSchedule",
                        "type": {
                            "vec": {
                                "defined": "EmissionScheduleItem"
                            }
                        }
                    },
                    {
                        "name": "fracBurnRewards",
                        "type": "f32"
                    },
                    {
                        "name": "fracFulfillerWorkRewards",
                        "type": "f32"
                    },
                    {
                        "name": "fracFulfillerRewards",
                        "type": "f32"
                    },
                    {
                        "name": "bump",
                        "type": "u8"
                    }
                ]
            }
        },
        {
            "name": "emissionScheduleReceiptV0",
            "type": {
                "kind": "struct",
                "fields": [
                    {
                        "name": "epochId",
                        "type": "u64"
                    },
                    {
                        "name": "epochStartedAt",
                        "type": "i64"
                    },
                    {
                        "name": "epochEndedAt",
                        "type": "i64"
                    },
                    {
                        "name": "totalRndrBurned",
                        "type": "u64"
                    },
                    {
                        "name": "totalUptimeScore",
                        "type": "u64"
                    },
                    {
                        "name": "totalRenderScore",
                        "type": "u64"
                    },
                    {
                        "name": "bump",
                        "type": "u8"
                    }
                ]
            }
        }
    ],
    "types": [
        {
            "name": "InitializeEmissionScheduleArgsV0",
            "type": {
                "kind": "struct",
                "fields": [
                    {
                        "name": "authority",
                        "type": "publicKey"
                    },
                    {
                        "name": "emissionSchedule",
                        "type": {
                            "vec": {
                                "defined": "EmissionScheduleItem"
                            }
                        }
                    },
                    {
                        "name": "fracBurnRewards",
                        "type": "f32"
                    },
                    {
                        "name": "fracFulfillerRewards",
                        "type": "f32"
                    },
                    {
                        "name": "fracFulfillerWorkRewards",
                        "type": "f32"
                    },
                    {
                        "name": "epochDurationSec",
                        "type": "i64"
                    }
                ]
            }
        },
        {
            "name": "UpdateBurnedRenderCreditsArgsV0",
            "type": {
                "kind": "struct",
                "fields": [
                    {
                        "name": "rndrBurned",
                        "type": "u64"
                    }
                ]
            }
        },
        {
            "name": "UpdateEmissionScheduleArgsV0",
            "type": {
                "kind": "struct",
                "fields": [
                    {
                        "name": "emissionSchedule",
                        "type": {
                            "option": {
                                "vec": {
                                    "defined": "EmissionScheduleItem"
                                }
                            }
                        }
                    },
                    {
                        "name": "epochId",
                        "type": {
                            "option": "u64"
                        }
                    }
                ]
            }
        },
        {
            "name": "UpdateNodeStatsArgsV0",
            "type": {
                "kind": "struct",
                "fields": [
                    {
                        "name": "entityKey",
                        "type": "publicKey"
                    },
                    {
                        "name": "renderDelta",
                        "type": {
                            "option": "u64"
                        }
                    },
                    {
                        "name": "uptimeDelta",
                        "type": {
                            "option": "u64"
                        }
                    }
                ]
            }
        },
        {
            "name": "EmissionScheduleItem",
            "type": {
                "kind": "struct",
                "fields": [
                    {
                        "name": "startUnixTime",
                        "type": "i64"
                    },
                    {
                        "name": "emissionsPerEpoch",
                        "type": "u64"
                    }
                ]
            }
        }
    ]
};
//# sourceMappingURL=emission_schedule.js.map